==> phoenix_widgets-1.6.6.tar.gz: lib/phoenix_bottom_menu_uhf.dart <==
import 'package:flutter/material.dart';

int selectedIndex = 0;

class PhoenixBottomMenuUHF extends StatelessWidget {
  const PhoenixBottomMenuUHF(
      {Key? key,
      required this.navBarItems,
      required this.onTabChange,
      this.selectedTabColor,
      this.unselectedTabColor,
      this.elevation,
      this.backgroundColor,
      this.bottomNavBarType})
      : super(key: key);

  final Function(int index) onTabChange;

  /// Set of navigation bar item in array
  final List<NavBarItem> navBarItems;

  /// Navigation bar decoration
  final Color? selectedTabColor;
  final Color? unselectedTabColor;
  final double? elevation;
  final Color? backgroundColor;
  final BottomNavigationBarType? bottomNavBarType;

  @override
  Widget build(BuildContext context) {
    return BottomNavigationBar(
        type: bottomNavBarType ?? BottomNavigationBarType.fixed,
        elevation: elevation,
        backgroundColor: backgroundColor,
        currentIndex: selectedIndex,
        selectedItemColor: selectedTabColor ?? Colors.red,
        unselectedItemColor: unselectedTabColor ?? Colors.black54,
        items: bottomNavigationBarItem(selectedTabColor ?? Colors.red,
            unselectedTabColor ?? Colors.black54, navBarItems),

        /// Callback the navigation Bar to widget
        onTap: (index) {
          selectedIndex = index;
          onTabChange(index);
        });
  }

  /// Loop set of list according for navigation bar item
  bottomNavigationBarItem(Color _selectedTabColor, Color _unselectedTabColor,
      List<NavBarItem> items) {
    List<BottomNavigationBarItem> listItem = <BottomNavigationBarItem>[];
    for (int num = 0; num < items.length; num++) {
      listItem.add(BottomNavigationBarItem(
          icon: Image.asset(items[num].image!,
              color: selectedIndex == num
                  ? _selectedTabColor
                  : _unselectedTabColor,
              height: 25,
              width: 25),
          label: items[num].name!));
    }
    return listItem;
  }
}

class NavBarItem {
  String? image;
  String? name;

  NavBarItem(this.name, this.image);
}

==> phoenix_widgets-1.7.1.tar.gz: lib/phoenix_bottom_menu_uhf.dart <==
import 'package:flutter/material.dart';

int selectedIndex = 0;

class PhoenixBottomMenuUHF extends StatelessWidget {
  const PhoenixBottomMenuUHF({
    Key? key,
    required this.navBarItems,
    required this.onTabChange,
    this.selectedTabColor,
    this.unselectedTabColor,
    this.elevation,
    this.backgroundColor,
    this.bottomNavBarType,
    this.iconSize = 25,
  }) : super(key: key);

  final Function(int index) onTabChange;

  /// Set of navigation bar item in array
  final List<NavBarItem> navBarItems;

  /// Navigation bar decoration
  final Color? selectedTabColor;
  final Color? unselectedTabColor;
  final double? elevation;
  final Color? backgroundColor;
  final BottomNavigationBarType? bottomNavBarType;
  final double? iconSize;

  @override
  Widget build(BuildContext context) {
    return BottomNavigationBar(
        type: bottomNavBarType ?? BottomNavigationBarType.fixed,
        elevation: elevation,
        backgroundColor: backgroundColor,
        currentIndex: selectedIndex,
        selectedItemColor: selectedTabColor ?? Colors.red,
        unselectedItemColor: unselectedTabColor ?? Colors.black54,
        items: bottomNavigationBarItem(selectedTabColor ?? Colors.red,
            unselectedTabColor ?? Colors.black54, navBarItems),

        /// Callback the navigation Bar to widget
        onTap: (index) {
          selectedIndex = index;
          onTabChange(index);
        });
  }

  /// Loop set of list according for navigation bar item
  bottomNavigationBarItem(Color _selectedTabColor, Color _unselectedTabColor,
      List<NavBarItem> items) {
    List<BottomNavigationBarItem> listItem = <BottomNavigationBarItem>[];
    for (int num = 0; num < items.length; num++) {
      listItem.add(
        BottomNavigationBarItem(
          activeIcon: items[num].selectedImage,
          icon: items[num].image,
          label: items[num].name!,
        ),
      );
    }
    return listItem;
  }
}

class NavBarItem {
  Widget image;
  Widget? selectedImage;
  String? name;

  NavBarItem({required this.image, this.name, this.selectedImage});
}
